@@ -416,8 +416,6 @@ Ext.m3.ObjectGrid = Ext.extend(Ext.m3.GridPanel, {
     }
 });
 
-Ext.reg('objectgrid', Ext.m3.ObjectGrid);
-
 Ext.m3.EditorObjectGrid = Ext.extend(Ext.m3.EditorGridPanel, {
 	constructor: function(baseConfig, params){
 
@@ -690,5 +688,3 @@ Ext.m3.EditorObjectGrid = Ext.extend(Ext.m3.EditorGridPanel, {
 		return baseConf;
     }
 });
-
-Ext.reg('editorobjectgrid', Ext.m3.EditorObjectGrid);
